summaryrefslogtreecommitdiff
path: root/test/files/neg/t3160ambiguous.scala
diff options
context:
space:
mode:
Diffstat (limited to 'test/files/neg/t3160ambiguous.scala')
-rw-r--r--test/files/neg/t3160ambiguous.scala10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/files/neg/t3160ambiguous.scala b/test/files/neg/t3160ambiguous.scala
index cb9759b79c..57745e60d8 100644
--- a/test/files/neg/t3160ambiguous.scala
+++ b/test/files/neg/t3160ambiguous.scala
@@ -1,15 +1,15 @@
object Bippy {
- private class Node
+ private class List[+T]
}
class Bippy {
import Bippy._
- import scala.xml._
+ import scala.collection.immutable._
- def f(x: Node): String = ??? // ambiguous, because Bippy.Node is accessible
+ def f(x: List[Any]): String = ??? // ambiguous, because Bippy.List is accessible
}
class Other {
import Bippy._
- import scala.xml._
+ import scala.collection.immutable._
- def f(x: Node): String = ??? // unambiguous, because Bippy.Node is inaccessible
+ def f(x: List[Any]): String = ??? // unambiguous, because Bippy.List is inaccessible
}